From f8bd89d27323403dd9de9772a7974b439b37b29d Mon Sep 17 00:00:00 2001
From: Hisham <hisham@gobolinux.org>
Date: Sat, 29 Oct 2016 21:52:20 -0200
Subject: Fix references to writer.make_manifest

---
 src/luarocks/manif/writer.lua | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/src/luarocks/manif/writer.lua b/src/luarocks/manif/writer.lua
index df971fca..daa6b005 100644
--- a/src/luarocks/manif/writer.lua
+++ b/src/luarocks/manif/writer.lua
@@ -353,10 +353,10 @@ function writer.add_to_manifest(name, version, repo, deps_mode)
    local manifest, err = manif.load_local_manifest(rocks_dir)
    if not manifest then
       util.printerr("No existing manifest. Attempting to rebuild...")
       -- Manifest built by `manif.make_manifest` should already
       -- include information about given name and version,
       -- no need to update it.
-      return manif.make_manifest(rocks_dir, deps_mode)
+      return writer.make_manifest(rocks_dir, deps_mode)
    end
 
    local results = {[name] = {[version] = {{arch = "installed", repo = rocks_dir}}}}
@@ -390,9 +390,9 @@ function writer.remove_from_manifest(name, version, repo, deps_mode)
    local manifest, err = manif.load_local_manifest(rocks_dir)
    if not manifest then
       util.printerr("No existing manifest. Attempting to rebuild...")
       -- Manifest built by `manif.make_manifest` should already
       -- include up-to-date information, no need to update it.
-      return manif.make_manifest(rocks_dir, deps_mode)
+      return writer.make_manifest(rocks_dir, deps_mode)
    end
 
    local package_entry = manifest.repository[name]
@@ -353,10 +353,10 @@ function writer.add_to_manifest(name, version, repo, deps_mode)
    if not manifest then
       util.printerr("No existing manifest. Attempting to rebuild...")
-      -- Manifest built by `manif.make_manifest` should already
+      -- Manifest built by `writer.make_manifest` should already
       -- include information about given name and version,
       -- no need to update it.
@@ -390,9 +390,9 @@ function writer.remove_from_manifest(name, version, repo, deps_mode)
    if not manifest then
       util.printerr("No existing manifest. Attempting to rebuild...")
-      -- Manifest built by `manif.make_manifest` should already
+      -- Manifest built by `writer.make_manifest` should already
       -- include up-to-date information, no need to update it.
-- 
cgit v1.2.3-55-g6feb